@@ -15,14 +15,6 @@
 /*  `final' properties to an input string of character codes for the Arabic */
 /*  script.                                                                 */
 /*                                                                          */
-/*  This file is part of the FreeType project, and may only be used         */
-/*  modified and distributed under the terms of the FreeType project        */
-/*  license, LICENSE.TXT.  By continuing to use, modify, or distribute      */
-/*  this file you indicate that you have read the license and               */
-/*  understand and accept it fully.                                         */
-/*                                                                          */
-/* The file LICENSE.TXT can be found in the Pango distribution as           */
-/* pango/opentype/FT-license.txt                                            */
 /****************************************************************************/
 
 #include "arabic-ot.h"
@@ -31,17 +23,17 @@
 /*
  *
  *     Here a table of the joining classes for characters in the range
- *     U+0620 - U+06FF and U+0750 - U+077F.
+ *     U+0620 - U+06FF.
  *
  *    The following character also has a joining class:
  *
- *     U+200D  ZERO WIDTH JOINER  -> causing
+ *     U+200C  ZERO WIDTH NON-JOINER  -> causing
  *
  *    All other characters are given the joining class `none'.
  *
  */
 
-static const joining_class  arabic[] =
+joining_class  arabic[] =
 {
   /* U+0620 */
   none, none, right, right,
@@ -62,16 +54,16 @@ static const joining_class  arabic[] =
   transparent, transparent, transparent, transparent,
 
   /* U+0650 */
-  transparent, transparent, transparent, transparent,
-  transparent, transparent, transparent, transparent,
-  transparent, transparent, transparent, transparent,
   transparent, transparent, transparent, none,
+  none, none, none, none,
+  none, none, none, none,
+  none, none, none, none,
 
   /* U+0660 */
   none, none, none, none,
   none, none, none, none,
   none, none, none, none,
-  none, none, dual, dual,
+  none, none, none, none,
 
   /* U+0670 */
   transparent, right, right, right,
@@ -119,34 +111,13 @@ static const joining_class  arabic[] =
   transparent, transparent, transparent, transparent,
   transparent, none, none, transparent,
   transparent, none, transparent, transparent,
-  transparent, transparent, right, right,
+  transparent, transparent, none, none,
 
   /* U+06F0 */
   none, none, none, none,
   none, none, none, none,
   none, none, dual, dual,
-  dual, none, none, dual
-};
-
-static const joining_class  arabic_supplement[] =
-{
-  /* U+0750 */
-  dual, dual, dual, dual,
-  dual, dual, dual, dual,
-  dual, right, right, right,
-  dual, dual, dual, dual,
-
-  /* U+0760 */
-  dual, dual, dual, dual,
-  dual, dual, dual, dual,
-  dual, dual, dual, right,
-  right, dual, none, none,
-
-  /* U+0770 */
-  none, none, none, none,
-  none, none, none, none,
-  none, none, none, none,
-  none, none, none, none
+  dual, none, none, none
 };
 
 #if 0
@@ -294,25 +265,25 @@ static joining_class  Get_Joining_Class (gunichar*   string,
 
       if (pos >= length)
         return none;
-
-      if (string[pos] >= 0x0620 &&
-          string[pos] < 0x0700)
-        j = arabic[string[pos] - 0x0620];
-      else if (string[pos] >= 0x0750 &&
-          string[pos] < 0x0780)
-        j = arabic_supplement[string[pos] - 0x0750];
-      else if (string[pos] == 0x200D)
-        return causing;
+      
+      if (string[pos] < 0x0620 ||
+	  string[pos] >= 0x0700)
+	{
+	  if (string[pos] == 0x200C)
+	    return causing;
+	  else
+	    return none;
+	}
       else
-        return none;
-
+        j =  arabic[string[pos] - 0x0620];
+      
       if (!direction || j != transparent)
         return j;
     }
 }
 
 
-FT_Error  Arabic_Assign_Properties (gunichar    *string,
+FT_Error  Assign_Arabic_Properties (gunichar    *string,
 				    gulong      *properties,
 				    int          length)
 {
